# One place to edit all the system messages seems like a good idea!

create_project = "Setting up a new project in '%s'"

nochange = """\
Hmm... nothing's changed in \"%s\" or \"%s\" since last time.
If you've removed pages, or included a template dynamically, try --force\
"""

built_n_of_n = "Built %s of %s pages in \"%s\" directory"
	
start_render = "Digesting \"%s\" files"
render_success = "\033[1;32mBuilding \033[0m\033[2m%s\033[0m > \033[34m%s \033[2m[%s]\033[0m"

watch_start = "Listening for changes in '%s', '%s'"
watch_change = "Change detected in %s"


parser_error = """\
%s does not parse %s, expected .%s. Check the 'data_format' in wrangler.yaml\
"""

parser_decode_error = "\033[31mCouldn't load %s as %s\033[0m"

file_created = "Created '%s'"
file_decode_error = "\033[31mTrouble reading %s\033[0m"
file_write_error = "\033[31mCouldn't write %s\033[0m"
already_exists = "Couldn't create '%s', it already exists"

write_log = "Wrote log to: \033[32m%s\033[0m"

unpickle_error = """\
Couldn't load %s from the cache. Try running `wrangler clean`\
then `wrangler build`, or build again with the `--nocache` option.
"""


import sys
import time
import logging
from watchdog.observers import Observer
from watchdog.events import LoggingEventHandler, FileSystemEventHandler
from blinker import signal


class WatchEventHandler(FileSystemEventHandler):
    def on_any_event(self, event):
        if not event.is_directory:
            sig = signal('watch_change')
            sig.send(event)


class Watcher(object):
    def __init__(self, input_dir, templates_dir):

        paths = [input_dir, templates_dir]
        threads = []

        try:
            observer = Observer()
            event_handler = WatchEventHandler()

            for i in paths:
                targetPath = str(i)
                observer.schedule(event_handler, targetPath, recursive=True)
                threads.append(observer)

            observer.start()

            signal_watch_init = signal('watch_init')
            signal_watch_init.send(self)

            try:
                while True:
                    time.sleep(1)
            except KeyboardInterrupt:
                wrangler._reporter.log("Stopping with grace and poise", "green")
                observer.stop()
            
            observer.join()
        except:
            return None


from setuptools import setup

def readme():
    with open('README.rst') as f:
        return f.read()

setup(name='wrangler',
	version='0.1.8.1',
	description='A pythonic static site generator',
	long_description=readme(),
	url='http://github.com/springload/Wrangler.py',
	author='Springload',
	author_email='hello@springload.co.nz',
	license='MIT',
	packages=['wrangler'],
	package_dir={'wrangler': 'wrangler'},
	package_data={'wrangler': ['defaults/*']},
	install_requires=[
		'markdown',
		'jinja2',
		'argparse',
		'docutils',
		'pyyaml',
		'watchdog',
		'blinker'
	],
	scripts=['bin/wrangler'],
	zip_safe=False)